# Copyright 2004 Tom Rothamel <tom-renpy@onegeek.org>
# 
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import display
import executive
import image
import layout
from params import config
import widget

class GUI(executive.Executive):

    def __init__(self):
        super(GUI, self).__init__()
        
        display.init()
        widget.init()
        self.images = {}
        self.shown = {}

    def interact(self, widget):
        try:
            display.show(widget)
            display.interact(self)
        finally:            
            display.hide(widget)

    def ui_clear_scene(self):
        display.clear()
        self.shown = {}

    def ui_show(self, t, with):
        showable = self.images[t]
        # TODO: Do something if with is not None.

        self.shown[t] = showable
        display.show(showable)

    def ui_hide(self, t, with=None):
        if t in self.shown:
            display.hide(self.shown[t])

        # TODO:
        # If we're hiding with something, we want to display.show the
        # new thing.
        
    def ui_reshow_scene(self):
        self.ui_clear_scene()
        for t in self.scene:
             self.ui_show(t, None)
        
    def ui_dialogue_1(self, what):
        msg = widget.MessageBox(what)
        anchor = layout.Anchor(msg, yo=config.display_yo)

        self.interact(anchor)
        
    def ui_dialogue_2(self, who, what):
        label = widget.LabelBox(who)
        msg = widget.MessageBox(what)
        vbox = layout.VBox(label, msg)
        anchor = layout.Anchor(vbox, yo=config.display_yo)

        self.interact(anchor)

    def ui_menu(self, label, choices):
        menu = widget.MenuBox(label, choices)
        anchor = layout.Anchor(menu, yo=config.display_yo)

        self.interact(anchor)

        return menu.choice

    def ui_centered(self, text):
        msg = widget.MessageBox(text, width=config.center_box_width, minheight=0)
        anchor = layout.Anchor(msg, valign="center")

        self.interact(anchor)
        
    def ui_center_menu(self, label, choices):
        menu = widget.MenuBox(label, choices, width=config.center_menu_width)
        anchor = layout.Anchor(menu, yo=config.display_yo, valign="center")

        self.interact(anchor)

        return menu.choice

    def ui_prompt(self, msg, limit, default=""):
        prompt = widget.PromptBox(msg, limit, default)
        anchor = layout.Anchor(prompt)

        self.interact(anchor)
        return prompt.content

    def ui_center_prompt(self, msg, limit, default=""):
        prompt = widget.PromptBox(msg, limit, default,
                                  width=config.center_prompt_width,
                                  minheight = 0)

        anchor = layout.Anchor(prompt, valign="center")

        self.interact(anchor)

        return prompt.content
        

    def ui_image(self, t, code):

        img = self.eval(code)
        img = display.full_construct(img)
        
        self.images[t] = img
            
