# Copyright 2004 Tom Rothamel <tom-renpy@onegeek.org>
# 
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import cStringIO

import pygame
from pygame.locals import *

import display
import loader
from params import config

def load_image(fn, key=None, alpha=None):

    if key is None:
        key = config.image_color_key

    # Hacky way of reading, exists to work around bugs in pygame,
    # or sdl, or something. (If it's not segfaulting, you know it's
    # working.)
    f = loader.load(fn, "rb")
    idata = f.read()
    f.close()
    
    f = cStringIO.StringIO(idata)
    surface = pygame.image.load(f, fn)
    f.close()
    
    if key:
        surface.set_colorkey(key, RLEACCEL)

    surface = surface.convert_alpha()
    
    if alpha is not None:
        pa = pygame.surfarray.pixels_alpha(surface)

        na = pa * alpha
        na /= 100
        na = na.astype('b')

        pa[:,:] = na[:,:]
        
        del na
        del pa

    return surface

class image(display.Showable):

    def __init__(self, fn, key=None, alpha=None):
        self.fn = fn
        self.key = key
        self.surface = load_image(self.fn, self.key, alpha)
        
    def size(self):
        return self.surface.get_size()

    def draw(self, t):
        return t.blit(self.surface, 0, 0)
