# Copyright 2004 Tom Rothamel <tom-renpy@onegeek.org>
# 
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#!/usr/bin/python

import re
import tpg

import fragment
import loader
import script

# A list of all of the declarations that are known in the system.
declarations = []

def parse_script(fn):
    """
    This parses a script, and returns the first declaration statement and
    the first program statement.
    """

    stmt = parse_file(fn)
    fragment.nextify_list(declarations, None)
    fragment.make_frag_dict()

    return declarations[0], stmt

def parse_file(fn):
    """
    This parses a file that contains part of a script, and returns the
    first statement in that file.
    """
    
    f = loader.load(fn)
    sp = script.ScriptParser(f.read())

    decls, stmts = sp.start()

    declarations.extend(decls)
    fragment.nextify_list(stmts, None)

    return stmts[0]
